@@ -1,5 +1,4 @@
 import logging
-import os
 import re
 
 from behave import then, when
@@ -7,7 +6,12 @@ from behave import then, when
 from features.steps.files import when_i_create_file_with_content
 from features.steps.packages import when_i_apt_install
 from features.steps.shell import when_i_run_command, when_i_run_shell_command
-from features.util import SUT, InstallationSource, build_debs
+from features.util import (
+    SUT,
+    InstallationSource,
+    build_debs,
+    get_debs_for_series,
+)
 
 
 @when("I install ubuntu-advantage-tools")
@@ -25,12 +29,7 @@ def when_i_install_uat(context, machine_name=SUT):
                 context, "ubuntu-advantage-pro", machine_name=machine_name
             )
     elif context.pro_config.install_from is InstallationSource.PREBUILT:
-        debs_path = context.pro_config.debs_path
-        deb_paths = [
-            os.path.join(debs_path, deb_file)
-            for deb_file in os.listdir(debs_path)
-            if series in deb_file
-        ]
+        deb_paths = get_debs_for_series(context.pro_config.debs_path, series)
         logging.info("using debs: {}".format(deb_paths))
         for deb_path in deb_paths:
             if "pro" not in deb_path or is_pro:
@@ -40,7 +39,10 @@ def when_i_install_uat(context, machine_name=SUT):
                 )
                 instance.execute("sudo rm /tmp/behave_ua.deb")
     elif context.pro_config.install_from is InstallationSource.LOCAL:
-        ua_deb_path, pro_deb_path = build_debs(series)
+        ua_deb_path, pro_deb_path = build_debs(
+            series,
+            sbuild_output_to_terminal=context.pro_config.sbuild_output_to_terminal,  # noqa: E501
+        )
         instance.push_file(ua_deb_path, "/tmp/behave_ua.deb")
         when_i_apt_install(
             context, "/tmp/behave_ua.deb", machine_name=machine_name
@@ -144,7 +146,10 @@ def when_i_install_uat(context, machine_name=SUT):
 @when("I have the `{series}` debs under test in `{dest}`")
 def when_i_have_the_debs_under_test(context, series, dest):
     if context.pro_config.install_from is InstallationSource.LOCAL:
-        deb_paths = build_debs(series)
+        deb_paths = build_debs(
+            series,
+            sbuild_output_to_terminal=context.pro_config.sbuild_output_to_terminal,  # noqa: E501
+        )
 
         for deb_path in deb_paths:
             tools_or_pro = "tools" if "tools" in deb_path else "pro"
@@ -203,7 +208,7 @@ def when_i_create_local_ppas(context, release, next_release):
     from features.steps.machines import given_a_machine
 
     # We need Kinetic or greater to support zstd when creating the PPAs
-    given_a_machine(context, "kinetic", "ppa")
+    given_a_machine(context, "lunar", machine_name="ppa")
     when_i_run_command(
         context, "apt-get update", "with sudo", machine_name="ppa"
     )
@@ -234,7 +239,10 @@ def create_local_ppa(context, release):
         "with sudo",
         machine_name="ppa",
     )
-    debs = build_debs(release)
+    debs = build_debs(
+        release,
+        sbuild_output_to_terminal=context.pro_config.sbuild_output_to_terminal,
+    )
     for deb in debs:
         deb_destination = "/tmp/" + deb.split("/")[-1]
         context.machines["ppa"].instance.push_file(deb, deb_destination)
@@ -256,7 +264,10 @@ def create_local_ppa(context, release):
 def when_i_install_pro(context, machine_name=SUT):
     if context.pro_config.install_from is InstallationSource.LOCAL:
         series = context.machines[machine_name].series
-        deb_paths = build_debs(series)
+        deb_paths = build_debs(
+            series,
+            sbuild_output_to_terminal=context.pro_config.sbuild_output_to_terminal,  # noqa: E501
+        )
 
         for deb_path in deb_paths:
             if "pro" in deb_path:
