@@ -13,8 +13,8 @@ SERIES_TO_VERSION = {
     "bionic": "18.04",
     "focal": "20.04",
     "jammy": "22.04",
-    "kinetic": "22.10",
     "lunar": "23.04",
+    "mantic": "23.10",
 }
 
 TOKEN_TO_ENVVAR = {
@@ -31,12 +31,12 @@ PLATFORM_SERIES_TESTS = {
     "awspro": ["xenial", "bionic", "focal", "jammy"],
     "awspro-fips": ["xenial", "bionic", "focal"],
     "docker": ["focal"],
-    "gcpgeneric": ["xenial", "bionic", "focal", "jammy", "kinetic"],
+    "gcpgeneric": ["xenial", "bionic", "focal", "jammy", "lunar"],
     "gcppro": ["xenial", "bionic", "focal", "jammy"],
     "gcppro-fips": ["bionic", "focal"],
-    "lxd": ["xenial", "bionic", "focal", "jammy", "kinetic", "lunar"],
-    "vm": ["xenial", "bionic", "focal", "jammy", "kinetic", "lunar"],
-    "upgrade": ["xenial", "bionic", "focal", "jammy", "kinetic"],
+    "lxd": ["xenial", "bionic", "focal", "jammy", "lunar", "mantic"],
+    "vm": ["xenial", "bionic", "focal", "jammy", "lunar", "mantic"],
+    "upgrade": ["xenial", "bionic", "focal", "jammy", "lunar"],
 }
 
 
