@@ -1,3 +1,5 @@
+import copy
+import enum
 import logging
 import socket
 from typing import Any, Dict, List, Optional, Tuple
@@ -6,41 +8,73 @@ from uaclient import (
     clouds,
     event_logger,
     exceptions,
+    http,
     messages,
-    serviceclient,
     system,
     util,
+    version,
 )
+from uaclient.api.u.pro.status.enabled_services.v1 import _enabled_services
+from uaclient.api.u.pro.status.is_attached.v1 import _is_attached
 from uaclient.config import UAConfig
-from uaclient.defaults import ATTACH_FAIL_DATE_FORMAT
-from uaclient.entitlements.entitlement_status import UserFacingStatus
+from uaclient.defaults import (
+    ATTACH_FAIL_DATE_FORMAT,
+    CONTRACT_EXPIRY_GRACE_PERIOD_DAYS,
+    CONTRACT_EXPIRY_PENDING_DAYS,
+)
+from uaclient.files.state_files import attachment_data_file
+from uaclient.http import serviceclient
 
-API_V1_CONTEXT_MACHINE_TOKEN = "/v1/context/machines/token"
-API_V1_TMPL_CONTEXT_MACHINE_TOKEN_RESOURCE = (
+# Here we describe every endpoint from the ua-contracts
+# service that is used by this client implementation.
+API_V1_ADD_CONTRACT_MACHINE = "/v1/context/machines/token"
+API_V1_GET_CONTRACT_MACHINE = (
     "/v1/contracts/{contract}/context/machines/{machine}"
 )
-API_V1_RESOURCES = "/v1/resources"
-API_V1_TMPL_RESOURCE_MACHINE_ACCESS = (
+API_V1_UPDATE_CONTRACT_MACHINE = (
+    "/v1/contracts/{contract}/context/machines/{machine}"
+)
+API_V1_AVAILABLE_RESOURCES = "/v1/resources"
+API_V1_GET_RESOURCE_MACHINE_ACCESS = (
     "/v1/resources/{resource}/context/machines/{machine}"
 )
-API_V1_AUTO_ATTACH_CLOUD_TOKEN = "/v1/clouds/{cloud_type}/token"
-API_V1_MACHINE_ACTIVITY = "/v1/contracts/{contract}/machine-activity/{machine}"
-API_V1_CONTRACT_INFORMATION = "/v1/contract"
+API_V1_GET_CONTRACT_TOKEN_FOR_CLOUD_INSTANCE = "/v1/clouds/{cloud_type}/token"
+API_V1_UPDATE_ACTIVITY_TOKEN = (
+    "/v1/contracts/{contract}/machine-activity/{machine}"
+)
+API_V1_GET_CONTRACT_USING_TOKEN = "/v1/contract"
 
-API_V1_MAGIC_ATTACH = "/v1/magic-attach"
+API_V1_GET_MAGIC_ATTACH_TOKEN_INFO = "/v1/magic-attach"
+API_V1_NEW_MAGIC_ATTACH = "/v1/magic-attach"
+API_V1_REVOKE_MAGIC_ATTACH = "/v1/magic-attach"
 
-OVERRIDE_SELECTOR_WEIGHTS = {"series_overrides": 1, "series": 2, "cloud": 3}
+OVERRIDE_SELECTOR_WEIGHTS = {
+    "series_overrides": 1,
+    "series": 2,
+    "cloud": 3,
+    "variant": 4,
+}
 
 event = event_logger.get_event_logger()
+LOG = logging.getLogger(util.replace_top_level_logger_name(__name__))
+
+
+@enum.unique
+class ContractExpiryStatus(enum.Enum):
+    NONE = 0
+    ACTIVE = 1
+    ACTIVE_EXPIRED_SOON = 2
+    EXPIRED_GRACE_PERIOD = 3
+    EXPIRED = 4
 
 
 class UAContractClient(serviceclient.UAServiceClient):
-
     cfg_url_base_attr = "contract_url"
-    api_error_cls = exceptions.ContractAPIError
 
     @util.retry(socket.timeout, retry_sleeps=[1, 2, 2])
-    def request_contract_machine_attach(self, contract_token, machine_id=None):
+    def add_contract_machine(
+        self, contract_token, attachment_dt, machine_id=None
+    ):
         """Requests machine attach to the provided machine_id.
 
         @param contract_token: Token string providing authentication to
@@ -50,41 +84,66 @@ class UAContractClient(serviceclient.UAServiceClient):
 
         @return: Dict of the JSON response containing the machine-token.
         """
+        if not machine_id:
+            machine_id = system.get_machine_id(self.cfg)
+
         headers = self.headers()
         headers.update({"Authorization": "Bearer {}".format(contract_token)})
-        data = self._get_platform_data(machine_id)
-        machine_token, _headers = self.request_url(
-            API_V1_CONTEXT_MACHINE_TOKEN, data=data, headers=headers
+        activity_info = self._get_activity_info()
+        activity_info["lastAttachment"] = attachment_dt.isoformat()
+        data = {"machineId": machine_id, "activityInfo": activity_info}
+        backcompat_data = _support_old_machine_info(data)
+        response = self.request_url(
+            API_V1_ADD_CONTRACT_MACHINE, data=backcompat_data, headers=headers
         )
-        self.cfg.machine_token_file.write(machine_token)
+        if response.code == 401:
+            raise exceptions.AttachInvalidTokenError()
+        elif response.code == 403:
+            msg = _create_attach_forbidden_message(response)
+            raise exceptions.UserFacingError(
+                msg=msg.msg,
+                msg_code=msg.name,
+                additional_info=msg.additional_info,
+            )
+        if response.code != 200:
+            raise exceptions.ContractAPIError(
+                API_V1_ADD_CONTRACT_MACHINE, response.code, response.body
+            )
 
-        system.get_machine_id.cache_clear()
-        machine_id = machine_token.get("machineTokenInfo", {}).get(
-            "machineId", data.get("machineId")
-        )
-        self.cfg.write_cache("machine-id", machine_id)
+        return response.json_dict
 
-        return machine_token
-
-    def request_resources(self) -> Dict[str, Any]:
+    def available_resources(self) -> Dict[str, Any]:
         """Requests list of entitlements available to this machine type."""
-        resource_response, headers = self.request_url(
-            API_V1_RESOURCES, query_params=self._get_platform_basic_info()
+        activity_info = self._get_activity_info()
+        response = self.request_url(
+            API_V1_AVAILABLE_RESOURCES,
+            query_params={
+                "architecture": activity_info["architecture"],
+                "series": activity_info["series"],
+                "kernel": activity_info["kernel"],
+                "virt": activity_info["virt"],
+            },
         )
-        return resource_response
+        if response.code != 200:
+            raise exceptions.ContractAPIError(
+                API_V1_AVAILABLE_RESOURCES, response.code, response.body
+            )
+        return response.json_dict
 
-    def request_contract_information(
-        self, contract_token: str
-    ) -> Dict[str, Any]:
+    def get_contract_using_token(self, contract_token: str) -> Dict[str, Any]:
         headers = self.headers()
         headers.update({"Authorization": "Bearer {}".format(contract_token)})
-        response_data, _response_headers = self.request_url(
-            API_V1_CONTRACT_INFORMATION, headers=headers
+        response = self.request_url(
+            API_V1_GET_CONTRACT_USING_TOKEN, headers=headers
         )
-        return response_data
+        if response.code != 200:
+            raise exceptions.ContractAPIError(
+                API_V1_GET_CONTRACT_USING_TOKEN, response.code, response.body
+            )
+        return response.json_dict
 
     @util.retry(socket.timeout, retry_sleeps=[1, 2, 2])
-    def request_auto_attach_contract_token(
+    def get_contract_token_for_cloud_instance(
         self, *, instance: clouds.AutoAttachCloudInstance
     ):
         """Requests contract token for auto-attach images for Pro clouds.
@@ -93,28 +152,32 @@ class UAContractClient(serviceclient.UAServiceClient):
 
         @return: Dict of the JSON response containing the contract-token.
         """
-        try:
-            response, _headers = self.request_url(
-                API_V1_AUTO_ATTACH_CLOUD_TOKEN.format(
-                    cloud_type=instance.cloud_type
-                ),
-                data=instance.identity_doc,
-            )
-        except exceptions.ContractAPIError as e:
-            msg = e.api_error.get("message", "")
+        response = self.request_url(
+            API_V1_GET_CONTRACT_TOKEN_FOR_CLOUD_INSTANCE.format(
+                cloud_type=instance.cloud_type
+            ),
+            data=instance.identity_doc,
+        )
+        if response.code != 200:
+            msg = response.json_dict.get("message", "")
             if msg:
-                logging.debug(msg)
+                LOG.debug(msg)
                 raise exceptions.InvalidProImage(error_msg=msg)
-            raise e
+            raise exceptions.ContractAPIError(
+                API_V1_GET_CONTRACT_TOKEN_FOR_CLOUD_INSTANCE,
+                response.code,
+                response.body,
+            )
 
-        self.cfg.write_cache("contract-token", response)
-        return response
+        self.cfg.write_cache("contract-token", response.json_dict)
+        return response.json_dict
 
-    def request_resource_machine_access(
+    def get_resource_machine_access(
         self,
         machine_token: str,
         resource: str,
         machine_id: Optional[str] = None,
+        save_file: bool = True,
     ) -> Dict[str, Any]:
         """Requests machine access context for a given resource
 
@@ -123,6 +186,7 @@ class UAContractClient(serviceclient.UAServiceClient):
         @param resource: Entitlement name.
         @param machine_id: Optional unique system machine id. When absent,
             contents of /etc/machine-id will be used.
+        @save_file: If the machine access should be saved on the user machine
 
         @return: Dict of the JSON response containing entitlement accessInfo.
         """
@@ -130,31 +194,25 @@ class UAContractClient(serviceclient.UAServiceClient):
             machine_id = system.get_machine_id(self.cfg)
         headers = self.headers()
         headers.update({"Authorization": "Bearer {}".format(machine_token)})
-        url = API_V1_TMPL_RESOURCE_MACHINE_ACCESS.format(
+        url = API_V1_GET_RESOURCE_MACHINE_ACCESS.format(
             resource=resource, machine=machine_id
         )
-        resource_access, headers = self.request_url(url, headers=headers)
-        if headers.get("expires"):
-            resource_access["expires"] = headers["expires"]
-        self.cfg.write_cache(
-            "machine-access-{}".format(resource), resource_access
-        )
-        return resource_access
+        response = self.request_url(url, headers=headers)
+        if response.code != 200:
+            raise exceptions.ContractAPIError(
+                API_V1_GET_RESOURCE_MACHINE_ACCESS,
+                response.code,
+                response.body,
+            )
+        if response.headers.get("expires"):
+            response.json_dict["expires"] = response.headers["expires"]
+        if save_file:
+            self.cfg.write_cache(
+                "machine-access-{}".format(resource), response.json_dict
+            )
+        return response.json_dict
 
-    def request_machine_token_update(
-        self,
-        machine_token: str,
-        contract_id: str,
-        machine_id: Optional[str] = None,
-    ) -> Dict:
-        """Update existing machine-token for an attached machine."""
-        return self._request_machine_token_update(
-            machine_token=machine_token,
-            contract_id=contract_id,
-            machine_id=machine_id,
-        )
-
-    def report_machine_activity(self):
+    def update_activity_token(self):
         """Report current activity token and enabled services.
 
         This will report to the contracts backend all the current
@@ -164,21 +222,24 @@ class UAContractClient(serviceclient.UAServiceClient):
         machine_token = self.cfg.machine_token.get("machineToken")
         machine_id = system.get_machine_id(self.cfg)
 
-        request_data = self._get_activity_info(machine_id)
-        url = API_V1_MACHINE_ACTIVITY.format(
+        request_data = self._get_activity_info()
+        url = API_V1_UPDATE_ACTIVITY_TOKEN.format(
             contract=contract_id, machine=machine_id
         )
         headers = self.headers()
         headers.update({"Authorization": "Bearer {}".format(machine_token)})
 
-        response, _ = self.request_url(url, headers=headers, data=request_data)
+        response = self.request_url(url, headers=headers, data=request_data)
+        if response.code != 200:
+            raise exceptions.ContractAPIError(
+                url, response.code, response.body
+            )
 
         # We will update the `machine-token.json` based on the response
         # provided by the server. We expect the response to be
         # a full `activityInfo` object which belongs at the root of
         # `machine-token.json`
-        if response:
-
+        if response.json_dict:
             machine_token = self.cfg.machine_token
             # The activity information received as a response here
             # will not provide the information inside an activityInfo
@@ -186,7 +247,7 @@ class UAContractClient(serviceclient.UAServiceClient):
             # we reach the contract for attach and refresh requests.
             # Because of that, we will store the response directly on
             # the activityInfo key
-            machine_token["activityInfo"] = response
+            machine_token["activityInfo"] = response.json_dict
             self.cfg.machine_token_file.write(machine_token)
 
     def get_magic_attach_token_info(self, magic_token: str) -> Dict[str, Any]:
@@ -199,41 +260,46 @@ class UAContractClient(serviceclient.UAServiceClient):
         headers.update({"Authorization": "Bearer {}".format(magic_token)})
 
         try:
-            response, _ = self.request_url(
-                API_V1_MAGIC_ATTACH, headers=headers
+            response = self.request_url(
+                API_V1_GET_MAGIC_ATTACH_TOKEN_INFO, headers=headers
             )
-        except exceptions.ContractAPIError as e:
-            if hasattr(e, "code"):
-                if e.code == 401:
-                    raise exceptions.MagicAttachTokenError()
-                elif e.code == 503:
-                    raise exceptions.MagicAttachUnavailable()
-            raise e
         except exceptions.UrlError as e:
-            logging.exception(str(e))
+            LOG.exception(str(e))
             raise exceptions.ConnectivityError()
+        if response.code == 401:
+            raise exceptions.MagicAttachTokenError()
+        if response.code == 503:
+            raise exceptions.MagicAttachUnavailable()
+        if response.code != 200:
+            raise exceptions.ContractAPIError(
+                API_V1_GET_MAGIC_ATTACH_TOKEN_INFO,
+                response.code,
+                response.body,
+            )
 
-        return response
+        return response.json_dict
 
     def new_magic_attach_token(self) -> Dict[str, Any]:
         """Create a magic attach token for the user."""
         headers = self.headers()
 
         try:
-            response, _ = self.request_url(
-                API_V1_MAGIC_ATTACH,
+            response = self.request_url(
+                API_V1_NEW_MAGIC_ATTACH,
                 headers=headers,
                 method="POST",
             )
-        except exceptions.ContractAPIError as e:
-            if e.code == 503:
-                raise exceptions.MagicAttachUnavailable()
-            raise e
         except exceptions.UrlError as e:
-            logging.exception(str(e))
+            LOG.exception(str(e))
             raise exceptions.ConnectivityError()
+        if response.code == 503:
+            raise exceptions.MagicAttachUnavailable()
+        if response.code != 200:
+            raise exceptions.ContractAPIError(
+                API_V1_NEW_MAGIC_ATTACH, response.code, response.body
+            )
 
-        return response
+        return response.json_dict
 
     def revoke_magic_attach_token(self, magic_token: str):
         """Revoke a magic attach token for the user."""
@@ -241,25 +307,26 @@ class UAContractClient(serviceclient.UAServiceClient):
         headers.update({"Authorization": "Bearer {}".format(magic_token)})
 
         try:
-            self.request_url(
-                API_V1_MAGIC_ATTACH,
+            response = self.request_url(
+                API_V1_REVOKE_MAGIC_ATTACH,
                 headers=headers,
                 method="DELETE",
             )
-        except exceptions.ContractAPIError as e:
-            if hasattr(e, "code"):
-                if e.code == 400:
-                    raise exceptions.MagicAttachTokenAlreadyActivated()
-                elif e.code == 401:
-                    raise exceptions.MagicAttachTokenError()
-                elif e.code == 503:
-                    raise exceptions.MagicAttachUnavailable()
-            raise e
         except exceptions.UrlError as e:
-            logging.exception(str(e))
+            LOG.exception(str(e))
             raise exceptions.ConnectivityError()
+        if response.code == 400:
+            raise exceptions.MagicAttachTokenAlreadyActivated()
+        if response.code == 401:
+            raise exceptions.MagicAttachTokenError()
+        if response.code == 503:
+            raise exceptions.MagicAttachUnavailable()
+        if response.code != 200:
+            raise exceptions.ContractAPIError(
+                API_V1_REVOKE_MAGIC_ATTACH, response.code, response.body
+            )
 
-    def get_updated_contract_info(
+    def get_contract_machine(
         self,
         machine_token: str,
         contract_id: str,
@@ -274,27 +341,35 @@ class UAContractClient(serviceclient.UAServiceClient):
             contents of /etc/machine-id will be used.
         """
         if not machine_id:
-            machine_id = self._get_platform_data(machine_id).get(
-                "machineId", None
-            )
+            machine_id = system.get_machine_id(self.cfg)
+
         headers = self.headers()
         headers.update({"Authorization": "Bearer {}".format(machine_token)})
-        url = API_V1_TMPL_CONTEXT_MACHINE_TOKEN_RESOURCE.format(
+        url = API_V1_GET_CONTRACT_MACHINE.format(
             contract=contract_id,
             machine=machine_id,
         )
-        response, headers = self.request_url(
+        activity_info = self._get_activity_info()
+        response = self.request_url(
             url,
             method="GET",
             headers=headers,
-            query_params=self._get_platform_basic_info(),
-            timeout=2,
+            query_params={
+                "architecture": activity_info["architecture"],
+                "series": activity_info["series"],
+                "kernel": activity_info["kernel"],
+                "virt": activity_info["virt"],
+            },
         )
-        if headers.get("expires"):
-            response["expires"] = headers["expires"]
-        return response
+        if response.code != 200:
+            raise exceptions.ContractAPIError(
+                url, response.code, response.body
+            )
+        if response.headers.get("expires"):
+            response.json_dict["expires"] = response.headers["expires"]
+        return response.json_dict
 
-    def _request_machine_token_update(
+    def update_contract_machine(
         self,
         machine_token: str,
         contract_id: str,
@@ -310,81 +385,91 @@ class UAContractClient(serviceclient.UAServiceClient):
 
         @return: Dict of the JSON response containing refreshed machine-token
         """
+        if not machine_id:
+            machine_id = system.get_machine_id(self.cfg)
+
         headers = self.headers()
         headers.update({"Authorization": "Bearer {}".format(machine_token)})
-        data = self._get_platform_data(machine_id)
-        data["activityInfo"] = self._get_activity_info()
-        url = API_V1_TMPL_CONTEXT_MACHINE_TOKEN_RESOURCE.format(
-            contract=contract_id, machine=data["machineId"]
-        )
-        response, headers = self.request_url(
-            url, headers=headers, method="POST", data=data
-        )
-        if headers.get("expires"):
-            response["expires"] = headers["expires"]
-        machine_id = response.get("machineTokenInfo", {}).get(
-            "machineId", data.get("machineId")
-        )
-        return response
-
-    def update_files_after_machine_token_update(
-        self, response: Dict[str, Any]
-    ):
-        self.cfg.machine_token_file.write(response)
-        system.get_machine_id.cache_clear()
-        data = self._get_platform_data(None)
-        machine_id = response.get("machineTokenInfo", {}).get(
-            "machineId", data.get("machineId")
-        )
-        self.cfg.write_cache("machine-id", machine_id)
-
-    def _get_platform_data(self, machine_id):
-        """Return a dict of platform-related data for contract requests"""
-        if not machine_id:
-            machine_id = system.get_machine_id(self.cfg)
-        platform = system.get_platform_info()
-        platform_os = platform.copy()
-        arch = platform_os.pop("arch")
-        return {
+        data = {
             "machineId": machine_id,
-            "architecture": arch,
-            "os": platform_os,
+            "activityInfo": self._get_activity_info(),
         }
+        backcompat_data = _support_old_machine_info(data)
+        url = API_V1_UPDATE_CONTRACT_MACHINE.format(
+            contract=contract_id, machine=machine_id
+        )
+        response = self.request_url(
+            url, headers=headers, method="POST", data=backcompat_data
+        )
+        if response.code != 200:
+            raise exceptions.ContractAPIError(
+                url, response.code, response.body
+            )
+        if response.headers.get("expires"):
+            response.json_dict["expires"] = response.headers["expires"]
+        return response.json_dict
 
-    def _get_platform_basic_info(self):
-        """Return a dict of platform basic info for some contract requests"""
-        platform = system.get_platform_info()
-        return {
-            "architecture": platform["arch"],
-            "series": platform["series"],
-            "kernel": platform["kernel"],
-            "virt": platform["virt"],
-        }
-
-    def _get_activity_info(self, machine_id: Optional[str] = None):
+    def _get_activity_info(self):
         """Return a dict of activity info data for contract requests"""
-        from uaclient.entitlements import ENTITLEMENT_CLASSES
 
-        if not machine_id:
-            machine_id = system.get_machine_id(self.cfg)
+        machine_info = {
+            "distribution": system.get_release_info().distribution,
+            "kernel": system.get_kernel_info().uname_release,
+            "series": system.get_release_info().series,
+            "architecture": system.get_dpkg_arch(),
+            "desktop": system.is_desktop(),
+            "virt": system.get_virt_type(),
+            "clientVersion": version.get_version(),
+        }
 
-        # If the activityID is null we should provide the endpoint
-        # with the instance machine id as the activityID
-        activity_id = self.cfg.machine_token_file.activity_id or machine_id
-
-        enabled_services = [
-            ent(self.cfg).name
-            for ent in ENTITLEMENT_CLASSES
-            if ent(self.cfg).user_facing_status()[0] == UserFacingStatus.ACTIVE
-        ]
+        if _is_attached(self.cfg).is_attached:
+            enabled_services = _enabled_services(self.cfg).enabled_services
+            attachment_data = attachment_data_file.read()
+            activity_info = {
+                "activityID": self.cfg.machine_token_file.activity_id
+                or system.get_machine_id(self.cfg),
+                "activityToken": self.cfg.machine_token_file.activity_token,
+                "resources": [service.name for service in enabled_services],
+                "lastAttachment": attachment_data.attached_at.isoformat()
+                if attachment_data
+                else None,
+            }
+        else:
+            activity_info = {}
 
         return {
-            "activityID": activity_id,
-            "activityToken": self.cfg.machine_token_file.activity_token,
-            "resources": enabled_services,
+            **activity_info,
+            **machine_info,
         }
 
 
+def _support_old_machine_info(request_body: dict):
+    """
+    Transforms a request_body that has the new activity_info into a body that
+    includes both old and new forms of machineInfo/activityInfo
+
+    This is necessary because there may be old ua-airgapped contract
+    servers deployed that we need to support.
+    This function is used for attach and refresh calls.
+    """
+    activity_info = request_body.get("activityInfo", {})
+
+    return {
+        "machineId": request_body.get("machineId"),
+        "activityInfo": activity_info,
+        "architecture": activity_info.get("architecture"),
+        "os": {
+            "distribution": activity_info.get("distribution"),
+            "kernel": activity_info.get("kernel"),
+            "series": activity_info.get("series"),
+            # These two are required for old ua-airgapped but not sent anymore
+            # in the new activityInfo
+            "type": "Linux",
+            "release": system.get_release_info().release,
+        },
+    }
+
+
 def process_entitlements_delta(
     cfg: UAConfig,
     past_entitlements: Dict[str, Any],
@@ -413,12 +498,14 @@ def process_entitlements_delta(
 
     # We need to sort our entitlements because some of them
     # depend on other service to be enable first.
+    failed_services = []  # type: List[str]
     for name in entitlements_enable_order(cfg):
         try:
             new_entitlement = new_entitlements[name]
         except KeyError:
             continue
 
+        failed_services = []
         try:
             deltas, service_enabled = process_entitlement_delta(
                 cfg=cfg,
@@ -429,17 +516,17 @@ def process_entitlements_delta(
             )
         except exceptions.UserFacingError:
             delta_error = True
-            event.service_failed(name)
+            failed_services.append(name)
             with util.disable_log_to_console():
-                logging.error(
+                LOG.error(
                     "Failed to process contract delta for {name}:"
                     " {delta}".format(name=name, delta=new_entitlement)
                 )
         except Exception:
             unexpected_error = True
-            event.service_failed(name)
+            failed_services.append(name)
             with util.disable_log_to_console():
-                logging.exception(
+                LOG.exception(
                     "Unexpected error processing contract delta for {name}:"
                     " {delta}".format(name=name, delta=new_entitlement)
                 )
@@ -448,15 +535,19 @@ def process_entitlements_delta(
             # them, then we will mark that service as successfully enabled
             if service_enabled and deltas:
                 event.service_processed(name)
+    event.services_failed(failed_services)
     if unexpected_error:
-        raise exceptions.UserFacingError(
-            msg=messages.UNEXPECTED_ERROR.msg,
-            msg_code=messages.UNEXPECTED_ERROR.name,
+        raise exceptions.AttachFailureUnknownError(
+            failed_services=[
+                (name, messages.UNEXPECTED_ERROR) for name in failed_services
+            ]
         )
     elif delta_error:
-        raise exceptions.UserFacingError(
-            msg=messages.ATTACH_FAILURE_DEFAULT_SERVICES.msg,
-            msg_code=messages.ATTACH_FAILURE_DEFAULT_SERVICES.name,
+        raise exceptions.AttachFailureDefaultServices(
+            failed_services=[
+                (name, messages.ATTACH_FAILURE_DEFAULT_SERVICES)
+                for name in failed_services
+            ]
         )
 
 
@@ -500,10 +591,16 @@ def process_entitlement_delta(
                 orig=orig_access, new=new_access
             )
             raise exceptions.UserFacingError(msg=msg.msg, msg_code=msg.name)
+
+        variant = (
+            new_access.get("entitlements", {})
+            .get("obligations", {})
+            .get("use_selector", "")
+        )
         try:
-            ent_cls = entitlement_factory(cfg=cfg, name=name)
+            ent_cls = entitlement_factory(cfg=cfg, name=name, variant=variant)
         except exceptions.EntitlementNotFoundError as exc:
-            logging.debug(
+            LOG.debug(
                 'Skipping entitlement deltas for "%s". No such class', name
             )
             raise exc
@@ -516,11 +613,11 @@ def process_entitlement_delta(
 
 
 def _create_attach_forbidden_message(
-    e: exceptions.ContractAPIError,
+    response: http.HTTPResponse,
 ) -> messages.NamedMessage:
     msg = messages.ATTACH_EXPIRED_TOKEN
-    if hasattr(e, "api_error") and "info" in e.api_error:
-        info = e.api_error["info"]
+    info = response.json_dict.get("info")
+    if info:
         contract_id = info["contractId"]
         reason = info["reason"]
         reason_msg = None
@@ -558,77 +655,51 @@ def _create_attach_forbidden_message(
     return msg
 
 
-def request_updated_contract(
-    cfg, contract_token: Optional[str] = None, allow_enable=False
-):
+def refresh(cfg):
     """Request contract refresh from ua-contracts service.
 
-    Compare original token to new token and react to entitlement deltas.
-
     :param cfg: Instance of UAConfig for this machine.
-    :param contract_token: String contraining an optional contract token.
-    :param allow_enable: Boolean set True if allowed to perform the enable
-        operation. When False, a message will be logged to inform the user
-        about the recommended enabled service.
 
     :raise UserFacingError: on failure to update contract or error processing
         contract deltas
-    :raise UrlError: On failure to contact the server
+    :raise UrlError: On failure during a connection
     """
-    orig_token = cfg.machine_token
     orig_entitlements = cfg.machine_token_file.entitlements
-    if orig_token and contract_token:
-        msg = messages.UNEXPECTED_CONTRACT_TOKEN_ON_ATTACHED_MACHINE
-        raise exceptions.UserFacingError(msg=msg.msg, msg_code=msg.name)
+    orig_token = cfg.machine_token
+    machine_token = orig_token["machineToken"]
+    contract_id = orig_token["machineTokenInfo"]["contractInfo"]["id"]
+
     contract_client = UAContractClient(cfg)
-    if contract_token:  # We are a mid ua-attach and need to get machinetoken
-        try:
-            contract_client.request_contract_machine_attach(
-                contract_token=contract_token
-            )
-        except exceptions.UrlError as e:
-            if isinstance(e, exceptions.ContractAPIError):
-                if hasattr(e, "code"):
-                    if e.code == 401:
-                        raise exceptions.AttachInvalidTokenError()
-                    elif e.code == 403:
-                        msg = _create_attach_forbidden_message(e)
-                        raise exceptions.UserFacingError(
-                            msg=msg.msg,
-                            msg_code=msg.name,
-                            additional_info=msg.additional_info,
-                        )
-                raise e
-            with util.disable_log_to_console():
-                logging.exception(str(e))
-            raise exceptions.ConnectivityError()
-    else:
-        machine_token = orig_token["machineToken"]
-        contract_id = orig_token["machineTokenInfo"]["contractInfo"]["id"]
-        resp = contract_client.request_machine_token_update(
-            machine_token=machine_token, contract_id=contract_id
-        )
-        contract_client.update_files_after_machine_token_update(resp)
+    resp = contract_client.update_contract_machine(
+        machine_token=machine_token, contract_id=contract_id
+    )
+
+    cfg.machine_token_file.write(resp)
+    system.get_machine_id.cache_clear()
+    machine_id = resp.get("machineTokenInfo", {}).get(
+        "machineId", system.get_machine_id(cfg)
+    )
+    cfg.write_cache("machine-id", machine_id)
 
     process_entitlements_delta(
         cfg,
         orig_entitlements,
         cfg.machine_token_file.entitlements,
-        allow_enable,
+        allow_enable=False,
     )
 
 
 def get_available_resources(cfg: UAConfig) -> List[Dict]:
     """Query available resources from the contract server for this machine."""
     client = UAContractClient(cfg)
-    resources = client.request_resources()
+    resources = client.available_resources()
     return resources.get("resources", [])
 
 
 def get_contract_information(cfg: UAConfig, token: str) -> Dict[str, Any]:
     """Query contract information for a specific token"""
     client = UAContractClient(cfg)
-    return client.request_contract_information(token)
+    return client.get_contract_using_token(token)
 
 
 def is_contract_changed(cfg: UAConfig) -> bool:
@@ -644,9 +715,7 @@ def is_contract_changed(cfg: UAConfig) -> bool:
         return False
 
     contract_client = UAContractClient(cfg)
-    resp = contract_client.get_updated_contract_info(
-        machine_token, contract_id
-    )
+    resp = contract_client.get_contract_machine(machine_token, contract_id)
     resp_expiry = (
         resp.get("machineTokenInfo", {})
         .get("contractInfo", {})
@@ -684,11 +753,16 @@ def _get_override_weight(
 
 
 def _select_overrides(
-    entitlement: Dict[str, Any], series_name: str, cloud_type: str
+    entitlement: Dict[str, Any],
+    series_name: str,
+    cloud_type: str,
+    variant: Optional[str] = None,
 ) -> Dict[int, Dict[str, Any]]:
     overrides = {}
 
     selector_values = {"series": series_name, "cloud": cloud_type}
+    if variant:
+        selector_values["variant"] = variant
 
     series_overrides = entitlement.pop("series", {}).pop(series_name, {})
     if series_overrides:
@@ -696,7 +770,7 @@ def _select_overrides(
             OVERRIDE_SELECTOR_WEIGHTS["series_overrides"]
         ] = series_overrides
 
-    general_overrides = entitlement.pop("overrides", [])
+    general_overrides = copy.deepcopy(entitlement.get("overrides", []))
     for override in general_overrides:
         weight = _get_override_weight(
             override.pop("selector"), selector_values
@@ -708,7 +782,9 @@ def _select_overrides(
 
 
 def apply_contract_overrides(
-    orig_access: Dict[str, Any], series: Optional[str] = None
+    orig_access: Dict[str, Any],
+    series: Optional[str] = None,
+    variant: Optional[str] = None,
 ) -> None:
     """Apply series-specific overrides to an entitlement dict.
 
@@ -733,12 +809,14 @@ def apply_contract_overrides(
         )
 
     series_name = (
-        system.get_platform_info()["series"] if series is None else series
+        system.get_release_info().series if series is None else series
     )
     cloud_type, _ = get_cloud_type()
     orig_entitlement = orig_access.get("entitlement", {})
 
-    overrides = _select_overrides(orig_entitlement, series_name, cloud_type)
+    overrides = _select_overrides(
+        orig_entitlement, series_name, cloud_type, variant
+    )
 
     for _weight, overrides_to_apply in sorted(overrides.items()):
         for key, value in overrides_to_apply.items():
@@ -750,3 +828,30 @@ def apply_contract_overrides(
             else:
                 # Otherwise, replace it wholesale
                 orig_access["entitlement"][key] = value
+
+
+def get_contract_expiry_status(
+    cfg: UAConfig,
+) -> Tuple[ContractExpiryStatus, int]:
+    """Return a tuple [ContractExpiryStatus, num_days]"""
+    if not _is_attached(cfg).is_attached:
+        return ContractExpiryStatus.NONE, 0
+
+    grace_period = CONTRACT_EXPIRY_GRACE_PERIOD_DAYS
+    pending_expiry = CONTRACT_EXPIRY_PENDING_DAYS
+    remaining_days = cfg.machine_token_file.contract_remaining_days
+
+    # if unknown assume the worst
+    if remaining_days is None:
+        LOG.warning(
+            "contract effectiveTo date is null - assuming it is expired"
+        )
+        return ContractExpiryStatus.EXPIRED, -grace_period
+
+    if 0 <= remaining_days <= pending_expiry:
+        return ContractExpiryStatus.ACTIVE_EXPIRED_SOON, remaining_days
+    elif -grace_period <= remaining_days < 0:
+        return ContractExpiryStatus.EXPIRED_GRACE_PERIOD, remaining_days
+    elif remaining_days < -grace_period:
+        return ContractExpiryStatus.EXPIRED, remaining_days
+    return ContractExpiryStatus.ACTIVE, remaining_days
