@@ -7,8 +7,7 @@ import textwrap
 import mock
 import pytest
 
-from uaclient import event_logger, messages, status, util
-from uaclient.api.u.pro.status.is_attached.v1 import _is_attached
+from uaclient import event_logger, http, messages, util
 from uaclient.cli import (
     UA_AUTH_TOKEN_URL,
     action_attach,
@@ -23,7 +22,6 @@ from uaclient.exceptions import (
     MagicAttachInvalidParam,
     MagicAttachTokenError,
     NonRootUserError,
-    UrlError,
     UserFacingError,
 )
 from uaclient.testing.fakes import FakeFile
@@ -229,54 +227,10 @@ class TestActionAttach:
         }
         assert expected == json.loads(capsys.readouterr()[0])
 
-    @pytest.mark.parametrize(
-        "error_class, error_str",
-        (
-            (UrlError, "Forbidden"),
-            (UserFacingError, "Unable to attach default services"),
-        ),
+    @mock.patch(
+        M_PATH + "contract.UAContractClient.update_activity_token",
     )
-    @mock.patch("uaclient.system.should_reboot", return_value=False)
-    @mock.patch("uaclient.files.notices.NoticesManager.remove")
-    @mock.patch("uaclient.status.get_available_resources")
-    @mock.patch("uaclient.timer.update_messaging.update_motd_messages")
-    @mock.patch(M_PATH + "contract.request_updated_contract")
-    def test_status_updated_when_auto_enable_fails(
-        self,
-        request_updated_contract,
-        m_update_apt_and_motd_msgs,
-        _m_get_available_resources,
-        _m_remove_notice,
-        _m_should_reboot,
-        error_class,
-        error_str,
-        FakeConfig,
-        event,
-    ):
-        """If auto-enable of a service fails, attach status is updated."""
-        token = "contract-token"
-        args = mock.MagicMock(token=token, attach_config=None)
-        cfg = FakeConfig()
-        status.status(cfg=cfg)  # persist unattached status
-        # read persisted status cache from disk
-        orig_unattached_status = cfg.read_cache("status-cache")
-
-        def fake_request_updated_contract(cfg, contract_token, allow_enable):
-            cfg.machine_token_file.write(ENTITLED_MACHINE_TOKEN)
-            raise error_class(error_str)
-
-        request_updated_contract.side_effect = fake_request_updated_contract
-        with pytest.raises(SystemExit) as excinfo:
-            main_error_handler(action_attach)(args, cfg)
-
-        assert 1 == excinfo.value.code
-        assert _is_attached(cfg).is_attached
-        # Assert updated status cache is written to disk
-        assert orig_unattached_status != cfg.read_cache(
-            "status-cache"
-        ), "Did not persist on disk status during attach failure"
-        assert [mock.call(cfg)] == m_update_apt_and_motd_msgs.call_args_list
-
+    @mock.patch("uaclient.files.state_files.attachment_data_file.write")
     @mock.patch("uaclient.system.should_reboot", return_value=False)
     @mock.patch("uaclient.files.notices.NoticesManager.remove")
     @mock.patch("uaclient.timer.update_messaging.update_motd_messages")
@@ -291,6 +245,8 @@ class TestActionAttach:
         m_update_apt_and_motd_msgs,
         _m_remove_notice,
         _m_should_reboot,
+        _m_attachment_data_file_write,
+        m_update_activity_token,
         FakeConfig,
         event,
     ):
@@ -301,7 +257,7 @@ class TestActionAttach:
         args = mock.MagicMock(token=token, attach_config=None)
         cfg = FakeConfig()
 
-        def fake_contract_attach(contract_token):
+        def fake_contract_attach(contract_token, attachment_dt):
             cfg.machine_token_file.write(BASIC_MACHINE_TOKEN)
             return BASIC_MACHINE_TOKEN
 
@@ -312,9 +268,12 @@ class TestActionAttach:
         assert 0 == ret
         assert 1 == m_status.call_count
         assert 1 == m_format_tabular.call_count
-        expected_calls = [mock.call(contract_token=token)]
+        expected_calls = [
+            mock.call(contract_token=token, attachment_dt=mock.ANY)
+        ]
         assert expected_calls == contract_machine_attach.call_args_list
         assert [mock.call(cfg)] == m_update_apt_and_motd_msgs.call_args_list
+        assert 1 == m_update_activity_token.call_count
 
         # We need to do that since all config objects in this
         # test will share the same data dir. Since this will
@@ -349,33 +308,39 @@ class TestActionAttach:
         assert expected == json.loads(fake_stdout.getvalue())
 
     @pytest.mark.parametrize("auto_enable", (True, False))
+    @mock.patch(
+        M_PATH + "contract.UAContractClient.update_activity_token",
+    )
+    @mock.patch("uaclient.files.state_files.attachment_data_file.write")
     @mock.patch("uaclient.system.should_reboot", return_value=False)
     @mock.patch("uaclient.files.notices.NoticesManager.remove")
     @mock.patch("uaclient.status.get_available_resources")
     @mock.patch("uaclient.timer.update_messaging.update_motd_messages")
-    def test_auto_enable_passed_through_to_request_updated_contract(
+    @mock.patch(M_PATH + "_post_cli_attach")
+    @mock.patch(M_PATH + "actions.attach_with_token")
+    def test_auto_enable_passed_through_to_attach_with_token(
         self,
+        m_attach_with_token,
+        _m_post_cli_attach,
         m_update_apt_and_motd_msgs,
         _m_get_available_resources,
         _m_remove_notice,
         _m_should_reboot,
+        _m_attachment_data_file_write,
+        _m_update_activity_token,
         auto_enable,
         FakeConfig,
     ):
-        args = mock.MagicMock(auto_enable=auto_enable, attach_config=None)
-
-        def fake_contract_updates(cfg, contract_token, allow_enable):
-            cfg.machine_token_file.write(BASIC_MACHINE_TOKEN)
-            return True
+        args = mock.MagicMock(
+            auto_enable=auto_enable, attach_config=None, token="token"
+        )
 
         cfg = FakeConfig()
-        with mock.patch(M_PATH + "contract.request_updated_contract") as m_ruc:
-            m_ruc.side_effect = fake_contract_updates
-            action_attach(args, cfg)
+        action_attach(args, cfg)
 
-        expected_call = mock.call(mock.ANY, mock.ANY, allow_enable=auto_enable)
-        assert [expected_call] == m_ruc.call_args_list
-        assert [mock.call(cfg)] == m_update_apt_and_motd_msgs.call_args_list
+        assert [
+            mock.call(mock.ANY, token="token", allow_enable=auto_enable)
+        ] == m_attach_with_token.call_args_list
 
     def test_attach_config_and_token_mutually_exclusive(
         self,
@@ -389,12 +354,16 @@ class TestActionAttach:
             action_attach(args, cfg=cfg)
         assert e.value.msg == messages.ATTACH_TOKEN_ARG_XOR_CONFIG.msg
 
+    @mock.patch(
+        M_PATH + "contract.UAContractClient.update_activity_token",
+    )
     @mock.patch(M_PATH + "_post_cli_attach")
     @mock.patch(M_PATH + "actions.attach_with_token")
     def test_token_from_attach_config(
         self,
         m_attach_with_token,
         _m_post_cli_attach,
+        m_update_activity_token,
         FakeConfig,
     ):
         args = mock.MagicMock(
@@ -406,6 +375,7 @@ class TestActionAttach:
         assert [
             mock.call(mock.ANY, token="faketoken", allow_enable=True)
         ] == m_attach_with_token.call_args_list
+        assert 1 == m_update_activity_token.call_count
 
     def test_attach_config_invalid_config(
         self,
@@ -463,6 +433,9 @@ class TestActionAttach:
         assert expected == json.loads(capsys.readouterr()[0])
 
     @pytest.mark.parametrize("auto_enable", (True, False))
+    @mock.patch(
+        M_PATH + "contract.UAContractClient.update_activity_token",
+    )
     @mock.patch(
         M_PATH + "actions.enable_entitlement_by_name",
         return_value=(True, None),
@@ -482,6 +455,7 @@ class TestActionAttach:
         m_handle_unicode,
         m_attach_with_token,
         m_enable,
+        m_update_activity_token,
         auto_enable,
         FakeConfig,
         event,
@@ -508,6 +482,7 @@ class TestActionAttach:
             ] == m_enable.call_args_list
         else:
             assert [] == m_enable.call_args_list
+        assert 1 == m_update_activity_token.call_count
 
         args.attach_config = FakeFile(
             safe_dump({"token": "faketoken", "enable_services": ["cis"]})
@@ -541,6 +516,7 @@ class TestActionAttach:
             (Exception("error"), messages.UNEXPECTED_ERROR),
         ),
     )
+    @mock.patch("uaclient.files.state_files.attachment_data_file.write")
     @mock.patch("uaclient.entitlements.entitlements_enable_order")
     @mock.patch("uaclient.contract.process_entitlement_delta")
     @mock.patch("uaclient.contract.apply_contract_overrides")
@@ -553,6 +529,7 @@ class TestActionAttach:
         _m_apply_contract_overrides,
         m_process_entitlement_delta,
         m_enable_order,
+        _m_attachment_data_file_write,
         expected_exception,
         expected_msg,
         FakeConfig,
@@ -566,8 +543,11 @@ class TestActionAttach:
             ({"test": 123}, True),
             expected_exception,
         ]
-        m_request_url.return_value = (
-            {
+        m_request_url.return_value = http.HTTPResponse(
+            code=200,
+            headers={},
+            body="",
+            json_dict={
                 "machineToken": "not-null",
                 "machineTokenInfo": {
                     "machineId": "machine-id",
@@ -595,7 +575,7 @@ class TestActionAttach:
                     },
                 },
             },
-            None,
+            json_list=[],
         )
 
         fake_stdout = io.StringIO()
