@@ -20,8 +20,9 @@ Enable an Ubuntu Pro service.
 
 Arguments:
   service              the name(s) of the Ubuntu Pro services to enable. One
-                       of: cc-eal, cis, esm-apps, esm-infra, fips, fips-
-                       updates, livepatch, realtime-kernel, ros, ros-updates
+                       of: anbox-cloud, cc-eal, cis, esm-apps, esm-infra,
+                       fips, fips-updates, landscape, livepatch, realtime-
+                       kernel, ros, ros-updates
 
 Flags:
   -h, --help           show this help message and exit
@@ -36,7 +37,7 @@ Flags:
 """
 
 
-@mock.patch("uaclient.contract.request_updated_contract")
+@mock.patch("uaclient.contract.refresh")
 class TestActionEnable:
     @mock.patch("uaclient.cli.setup_logging")
     @mock.patch("uaclient.cli.contract.get_available_resources")
@@ -44,7 +45,7 @@ class TestActionEnable:
         self,
         _m_resources,
         _m_setup_logging,
-        _request_updated_contract,
+        _refresh,
         capsys,
         FakeConfig,
     ):
@@ -63,7 +64,7 @@ class TestActionEnable:
     def test_non_root_users_are_rejected(
         self,
         _m_resources,
-        _request_updated_contract,
+        _refresh,
         we_are_currently_root,
         capsys,
         event,
@@ -132,7 +133,7 @@ class TestActionEnable:
     def test_lock_file_exists(
         self,
         m_subp,
-        _request_updated_contract,
+        _refresh,
         capsys,
         event,
         FakeConfig,
@@ -193,7 +194,7 @@ class TestActionEnable:
     def test_unattached_error_message(
         self,
         m_we_are_currently_root,
-        _request_updated_contract,
+        _refresh,
         root,
         expected_error_template,
         capsys,
@@ -256,7 +257,7 @@ class TestActionEnable:
     def test_invalid_service_error_message(
         self,
         m_we_are_currently_root,
-        _request_updated_contract,
+        _refresh,
         root,
         expected_error_template,
         is_attached,
@@ -344,7 +345,7 @@ class TestActionEnable:
     def test_unattached_invalid_and_valid_service_error_message(
         self,
         m_we_are_currently_root,
-        _request_updated_contract,
+        _refresh,
         root,
         expected_error_template,
         event,
@@ -400,13 +401,17 @@ class TestActionEnable:
         assert expected == json.loads(fake_stdout.getvalue())
 
     @pytest.mark.parametrize("assume_yes", (True, False))
+    @mock.patch(
+        "uaclient.cli.contract.UAContractClient.update_activity_token",
+    )
     @mock.patch("uaclient.status.get_available_resources", return_value={})
     @mock.patch("uaclient.entitlements.valid_services")
     def test_assume_yes_passed_to_service_init(
         self,
         m_valid_services,
         _m_get_available_resources,
-        m_request_updated_contract,
+        _m_update_activity_token,
+        m_refresh,
         assume_yes,
         FakeConfig,
     ):
@@ -438,6 +443,7 @@ class TestActionEnable:
                 allow_beta=False,
                 called_name="testitlement",
                 access_only=False,
+                extra_args=None,
             )
         ] == m_entitlement_cls.call_args_list
 
@@ -449,7 +455,7 @@ class TestActionEnable:
         m_valid_services,
         m_entitlement_factory,
         _m_get_available_resources,
-        _m_request_updated_contract,
+        _m_refresh,
         event,
         FakeConfig,
     ):
@@ -522,6 +528,7 @@ class TestActionEnable:
                     allow_beta=False,
                     called_name=m_ent_cls.name,
                     access_only=False,
+                    extra_args=None,
                 )
             ] == m_ent_cls.call_args_list
 
@@ -567,7 +574,7 @@ class TestActionEnable:
         m_valid_services,
         m_entitlement_factory,
         _m_get_available_resources,
-        _m_request_updated_contract,
+        _m_refresh,
         beta_flag,
         event,
         FakeConfig,
@@ -663,6 +670,7 @@ class TestActionEnable:
                     allow_beta=beta_flag,
                     called_name=m_ent_cls.name,
                     access_only=False,
+                    extra_args=None,
                 )
             ] == m_ent_cls.call_args_list
 
@@ -703,11 +711,15 @@ class TestActionEnable:
         }
         assert expected == json.loads(fake_stdout.getvalue())
 
+    @mock.patch(
+        "uaclient.cli.contract.UAContractClient.update_activity_token",
+    )
     @mock.patch("uaclient.status.get_available_resources", return_value={})
     def test_print_message_when_can_enable_fails(
         self,
         _m_get_available_resources,
-        _m_request_updated_contract,
+        _m_update_activity_token,
+        _m_refresh,
         event,
         FakeConfig,
     ):
@@ -782,7 +794,7 @@ class TestActionEnable:
     )
     def test_invalid_service_names(
         self,
-        _m_request_updated_contract,
+        _m_refresh,
         service,
         beta,
         event,
@@ -848,13 +860,17 @@ class TestActionEnable:
         assert expected == json.loads(fake_stdout.getvalue())
 
     @pytest.mark.parametrize("allow_beta", ((True), (False)))
+    @mock.patch(
+        "uaclient.cli.contract.UAContractClient.update_activity_token",
+    )
     @mock.patch("uaclient.status.get_available_resources", return_value={})
     @mock.patch("uaclient.status.status")
     def test_entitlement_instantiated_and_enabled(
         self,
         m_status,
         _m_get_available_resources,
-        _m_request_updated_contract,
+        m_update_activity_token,
+        _m_refresh,
         allow_beta,
         event,
         FakeConfig,
@@ -888,6 +904,7 @@ class TestActionEnable:
                 allow_beta=allow_beta,
                 called_name="testitlement",
                 access_only=False,
+                extra_args=None,
             )
         ] == m_entitlement_cls.call_args_list
 
@@ -897,6 +914,7 @@ class TestActionEnable:
         assert [expected_enable_call] == m_entitlement.enable.call_args_list
         assert expected_ret == ret
         assert 1 == m_status.call_count
+        assert 1 == m_update_activity_token.call_count
 
         with mock.patch(
             "uaclient.entitlements.entitlement_factory",
